import * as React from 'react';
import { StyleProp, Animated, LayoutRectangle, View, ViewStyle } from 'react-native';
import { Theme, $Omit } from '../../types';
import { MenuItem as _MenuItem } from './MenuItem';
declare type Props = {
    /**
     * Whether the Menu is currently visible.
     */
    visible: boolean;
    /**
     * The anchor to open the menu from. In most cases, it will be a button that opens the menu.
     */
    anchor: React.ReactNode | {
        x: number;
        y: number;
    };
    /**
     * Extra margin to add at the top of the menu to account for translucent status bar on Android.
     * If you are using Expo, we assume translucent status bar and set a height for status bar automatically.
     * Pass `0` or a custom value to and customize it.
     * This is automatically handled on iOS.
     */
    statusBarHeight?: number;
    /**
     * Callback called when Menu is dismissed. The `visible` prop needs to be updated when this is called.
     */
    onDismiss: () => void;
    /**
     * Content of the `Menu`.
     */
    children: React.ReactNode;
    /**
     * Style of menu's inner content.
     */
    contentStyle?: StyleProp<ViewStyle>;
    style?: StyleProp<ViewStyle>;
    /**
     * @optional
     */
    theme: Theme;
};
declare type Layout = $Omit<$Omit<LayoutRectangle, 'x'>, 'y'>;
declare type State = {
    rendered: boolean;
    top: number;
    left: number;
    menuLayout: Layout;
    anchorLayout: Layout;
    opacityAnimation: Animated.Value;
    scaleAnimation: Animated.ValueXY;
};
/**
 * Menus display a list of choices on temporary elevated surfaces. Their placement varies based on the element that opens them.
 *
 *  <div class="screenshots">
 *   <img class="medium" src="screenshots/menu-1.png" />
 *   <img class="medium" src="screenshots/menu-2.png" />
 * </div>
 *
 * ## Usage
 * ```js
 * import * as React from 'react';
 * import { View } from 'react-native';
 * import { Button, Paragraph, Menu, Divider, Provider } from 'react-native-paper';
 *
 * export default class MyComponent extends React.Component {
 *   state = {
 *     visible: false,
 *   };
 *
 *   _openMenu = () => this.setState({ visible: true });
 *
 *   _closeMenu = () => this.setState({ visible: false });
 *
 *   render() {
 *     return (
 *       <Provider>
 *         <View
 *           style={{
 *             paddingTop: 50,
 *             flexDirection: 'row',
 *             justifyContent: 'center'
 *           }}>
 *           <Menu
 *             visible={this.state.visible}
 *             onDismiss={this._closeMenu}
 *             anchor={
 *               <Button onPress={this._openMenu}>Show menu</Button>
 *             }
 *           >
 *             <Menu.Item onPress={() => {}} title="Item 1" />
 *             <Menu.Item onPress={() => {}} title="Item 2" />
 *             <Divider />
 *             <Menu.Item onPress={() => {}} title="Item 3" />
 *           </Menu>
 *         </View>
 *       </Provider>
 *     );
 *   }
 * }
 * ```
 */
declare class Menu extends React.Component<Props, State> {
    static Item: (React.ComponentClass<Pick<{
        title: React.ReactNode;
        icon?: string | number | import("react-native").ImageURISource | import("react-native").ImageURISource[] | Readonly<{
            source: string | number | import("react-native").ImageURISource | import("react-native").ImageURISource[];
            direction: "rtl" | "ltr" | "auto";
        }> | ((props: {
            size: number;
            allowFontScaling?: boolean | undefined;
        } & {
            color: string;
        }) => React.ReactNode) | undefined;
        disabled?: boolean | undefined;
        onPress?: (() => void) | undefined;
        theme: Theme;
        style?: any;
    }, "style" | "title" | "icon" | "onPress" | "disabled"> & {
        theme?: import("@callstack/react-theme-provider").$DeepPartial<Theme> | undefined;
    }, any> & import("@callstack/react-theme-provider/typings/hoist-non-react-statics").NonReactStatics<(React.ComponentClass<{
        title: React.ReactNode;
        icon?: string | number | import("react-native").ImageURISource | import("react-native").ImageURISource[] | Readonly<{
            source: string | number | import("react-native").ImageURISource | import("react-native").ImageURISource[];
            direction: "rtl" | "ltr" | "auto";
        }> | ((props: {
            size: number;
            allowFontScaling?: boolean | undefined;
        } & {
            color: string;
        }) => React.ReactNode) | undefined;
        disabled?: boolean | undefined;
        onPress?: (() => void) | undefined;
        theme: Theme;
        style?: any;
    }, any> & typeof _MenuItem) | (React.FunctionComponent<{
        title: React.ReactNode;
        icon?: string | number | import("react-native").ImageURISource | import("react-native").ImageURISource[] | Readonly<{
            source: string | number | import("react-native").ImageURISource | import("react-native").ImageURISource[];
            direction: "rtl" | "ltr" | "auto";
        }> | ((props: {
            size: number;
            allowFontScaling?: boolean | undefined;
        } & {
            color: string;
        }) => React.ReactNode) | undefined;
        disabled?: boolean | undefined;
        onPress?: (() => void) | undefined;
        theme: Theme;
        style?: any;
    }> & typeof _MenuItem), {}>) | (React.FunctionComponent<Pick<{
        title: React.ReactNode;
        icon?: string | number | import("react-native").ImageURISource | import("react-native").ImageURISource[] | Readonly<{
            source: string | number | import("react-native").ImageURISource | import("react-native").ImageURISource[];
            direction: "rtl" | "ltr" | "auto";
        }> | ((props: {
            size: number;
            allowFontScaling?: boolean | undefined;
        } & {
            color: string;
        }) => React.ReactNode) | undefined;
        disabled?: boolean | undefined;
        onPress?: (() => void) | undefined;
        theme: Theme;
        style?: any;
    }, "style" | "title" | "icon" | "onPress" | "disabled"> & {
        theme?: import("@callstack/react-theme-provider").$DeepPartial<Theme> | undefined;
    }> & import("@callstack/react-theme-provider/typings/hoist-non-react-statics").NonReactStatics<(React.ComponentClass<{
        title: React.ReactNode;
        icon?: string | number | import("react-native").ImageURISource | import("react-native").ImageURISource[] | Readonly<{
            source: string | number | import("react-native").ImageURISource | import("react-native").ImageURISource[];
            direction: "rtl" | "ltr" | "auto";
        }> | ((props: {
            size: number;
            allowFontScaling?: boolean | undefined;
        } & {
            color: string;
        }) => React.ReactNode) | undefined;
        disabled?: boolean | undefined;
        onPress?: (() => void) | undefined;
        theme: Theme;
        style?: any;
    }, any> & typeof _MenuItem) | (React.FunctionComponent<{
        title: React.ReactNode;
        icon?: string | number | import("react-native").ImageURISource | import("react-native").ImageURISource[] | Readonly<{
            source: string | number | import("react-native").ImageURISource | import("react-native").ImageURISource[];
            direction: "rtl" | "ltr" | "auto";
        }> | ((props: {
            size: number;
            allowFontScaling?: boolean | undefined;
        } & {
            color: string;
        }) => React.ReactNode) | undefined;
        disabled?: boolean | undefined;
        onPress?: (() => void) | undefined;
        theme: Theme;
        style?: any;
    }> & typeof _MenuItem), {}>);
    static defaultProps: {
        statusBarHeight: any;
    };
    static getDerivedStateFromProps(nextProps: Props, prevState: State): {
        rendered: boolean;
    } | null;
    state: {
        rendered: boolean;
        top: number;
        left: number;
        menuLayout: {
            width: number;
            height: number;
        };
        anchorLayout: {
            width: number;
            height: number;
        };
        opacityAnimation: Animated.Value;
        scaleAnimation: Animated.ValueXY;
    };
    componentDidUpdate(prevProps: Props): void;
    componentWillUnmount(): void;
    _anchor?: View | null;
    _menu?: View | null;
    _isAnchorCoord: () => boolean;
    _measureMenuLayout: () => Promise<LayoutRectangle>;
    _measureAnchorLayout: () => Promise<LayoutRectangle>;
    _updateVisibility: () => Promise<void>;
    _isBrowser: () => boolean;
    _focusFirstDOMNode: (el: View | null | undefined) => void;
    _handleDismiss: () => boolean;
    _handleKeypress: (e: KeyboardEvent) => void;
    _attachListeners: () => void;
    _removeListeners: () => void;
    _show: () => Promise<void>;
    _hide: () => void;
    render(): JSX.Element;
}
declare const _default: (React.ComponentClass<Pick<Props, "style" | "children" | "anchor" | "visible" | "contentStyle" | "onDismiss" | "statusBarHeight"> & {
    theme?: import("@callstack/react-theme-provider").$DeepPartial<Theme> | undefined;
}, any> & import("@callstack/react-theme-provider/typings/hoist-non-react-statics").NonReactStatics<(React.ComponentClass<Props, any> & typeof Menu) | (React.FunctionComponent<Props> & typeof Menu), {}>) | (React.FunctionComponent<Pick<Props, "style" | "children" | "anchor" | "visible" | "contentStyle" | "onDismiss" | "statusBarHeight"> & {
    theme?: import("@callstack/react-theme-provider").$DeepPartial<Theme> | undefined;
}> & import("@callstack/react-theme-provider/typings/hoist-non-react-statics").NonReactStatics<(React.ComponentClass<Props, any> & typeof Menu) | (React.FunctionComponent<Props> & typeof Menu), {}>);
export default _default;
